==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sr.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Белешке",
    "The last viewed note cannot be accessed. " : "Не може се приступити последње прегледаној белешци.",
    "The notes folder is not accessible: %s" : "Фасцикла са белешкама није доступна: %s",
    "Error" : "Грешка",
    "New note" : "Нова белешка",
    "Distraction-free notes and writing" : "Белешке и писање без ометања",
    "Settings" : "Поставке",
    "Deleted {title}" : "Обрисана {title}",
    "Deleted {number} notes" : "Обрисано {number} белешка/е",
    "Undo Delete" : "Опозови брисање",
    "Please chose a valid path in {label} (bottom left corner)." : "Одаберите исправну путању у {label} (доњи леви угао).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Има несачуваних белешки. Напуштањем стране ћете поништити све измене!",
    "Folder to store your notes" : "Фасцикла за складиштење белешки",
    "path to notes" : "путања до белешки",
    "File extension for new notes" : "Екстензија фајлова код нових белешки",
    "All notes" : "Све белешке",
    "Categories" : "Категорије",
    "No search result for “{search}” in {category}" : "Нема резултата претраге за „{search}“ у категорији {category}",
    "No search result for “{search}”" : "Нема резултата претраге за „{search}“",
    "Loading …" : "Учитавање…",
    "Search result for “{search}” in {category}" : "Резултати претраге за „{search}“ у категорији {category}",
    "Search result for “{search}”" : "Резултати претраге за „{search}“",
    "Today" : "Данас",
    "Yesterday" : "Јуче",
    "This week" : "Ове недеље",
    "Last week" : "Прошле недеље",
    "This month" : "Овог месеца",
    "Last month" : "Прошлог месеца",
    "Rename" : "Преименуј",
    "Note's title" : "Наслов белешке",
    "Delete note" : "Обриши белешку",
    "Remove from favorites" : "Уклони из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "Error during preparing note for deletion." : "Грешка приликом припремања белешке за брисање.",
    "Empty note" : "Празна белешка",
    "Write …" : "Пиши…",
    "Details" : "Детаљи",
    "Preview" : "Претпреглед",
    "Edit" : "Измени",
    "Exit full screen" : "Напусти цео екран",
    "Full screen" : "Цео екран",
    "Save failed. Click to retry." : "Грешка при чувању. Кликните да покушате поново.",
    "Set category" : "Одаберите категорију",
    "Category" : "Категорија",
    "Uncategorized" : "Некатегоризовано",
    "Click here to save manually" : "Кликните овде да сачувате ручно",
    "Saving failed!" : "Снимање није успело!",
    "Last modified: {date}" : "Последња измена: {date}",
    "Note has unsaved changes" : "Белешка има несачуваних измена",
    "Subcategory" : "Подкатегорија",
    "_%n word_::_%n words_" : ["%n реч","%n речи","%n речи"],
    "Write down your thoughts without any distractions." : "Запишите Ваше мисли без ометања.",
    "Use Markdown markups to style your text." : "Користите Markdown језик да стилизујете текст.",
    "Organize your notes in categories." : "Организујте белешке у категорије.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте апликацију за мобилни да приступите Вашим белешкама где год да се налазите.",
    "Android app" : "Андроид апликација",
    "iOS app" : "iOS апликација",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Крените да пишете белешке кликајући „{newnote}“ из навигације апликације.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да направите подкатегорије користећи „/“ као разграничавач између категорије родитеља и подкатегорије, нпр. „{parent}/{sub}“",
    "See JavaScript console and server log for details." : "Погледајте JavaScript конзолу и дневник са сервера за детаље.",
    "Saving the note has failed due to insufficient storage." : "Чување белешке није успело звог недовољно простора.",
    "Updating settings has failed." : "Ажурирање подешавања није успело.",
    "Fetching notes has failed." : "Дохватање белешки није успело.",
    "Fetching note {id} has failed." : "Дохватање белешке {id} није успело.",
    "Renaming note {id} has failed." : "Преименовање белешке {id} није успело.",
    "Creating new note has failed." : "Прављење нове белешке није успело.",
    "Updating note {id} has failed." : "Ажурирање белешке {id} није успело.",
    "Undo delete has failed for note {title}." : "Опозивање брисања није успело за белешку {title}.",
    "Deleting note {id} has failed." : "Брисање белешке {id} није успело.",
    "Toggling favorite for note {id} has failed." : "Стављање/уклањање омиљене белешке {id} није успело.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешно ажурирање категорије белешке. Да ли у одредишни директоријум може да се пише?",
    "Updating the category for note {id} has failed." : "Ажурирање категорије белешке {id} није успело.",
    "Development Mode" : "Развојни режим",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Изгледа да је апликација белешки инсталирана из развојног извора. Молимо да је инсталирате из званичне <a href=\"%1$s\">Некстклауд продавнице</a>. Ако желите само да искомпајлирате апликацију Белешки, пратите <a href=\"%2$s\">инструкције за програмере</a>."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-notes-3.6.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sr.js <==
OC.L10N.register(
    "notes",
    {
    "Reading notes from filesystem has failed." : "Читање белешки са система фајлова није успело.",
    "Error" : "Грешка",
    "New note" : "Нова белешка",
    "Notes" : "Белешке",
    "Distraction-free notes and writing" : "Белешке и писање без ометања",
    "Please see Nextcloud server log for details." : "Погледајте Некстклауд серверске логове за детаље.",
    "Deleted {title}" : "Обрисана {title}",
    "Deleted {number} notes" : "Обрисано {number} белешка/е",
    "Undo Delete" : "Опозови брисање",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Има несачуваних белешки. Напуштањем стране ћете поништити све измене!",
    "Settings" : "Поставке",
    "Folder to store your notes" : "Фасцикла за складиштење белешки",
    "path to notes" : "путања до белешки",
    "File extension for new notes" : "Екстензија фајлова код нових белешки",
    "All notes" : "Све белешке",
    "Categories" : "Категорије",
    "No search result for “{search}” in {category}" : "Нема резултата претраге за „{search}“ у категорији {category}",
    "No search result for “{search}”" : "Нема резултата претраге за „{search}“",
    "Loading …" : "Учитавање…",
    "Search result for “{search}” in {category}" : "Резултати претраге за „{search}“ у категорији {category}",
    "Search result for “{search}”" : "Резултати претраге за „{search}“",
    "Today" : "Данас",
    "Yesterday" : "Јуче",
    "This week" : "Ове недеље",
    "Last week" : "Прошле недеље",
    "This month" : "Овог месеца",
    "Last month" : "Прошлог месеца",
    "Rename" : "Преименуј",
    "Note's title" : "Наслов белешке",
    "Delete note" : "Обриши белешку",
    "Remove from favorites" : "Уклони из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "Error during preparing note for deletion." : "Грешка приликом припремања белешке за брисање.",
    "Empty note" : "Празна белешка",
    "Write …" : "Пиши…",
    "Details" : "Детаљи",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Измени",
    "Preview" : "Претпреглед",
    "Exit full screen" : "Напусти цео екран",
    "Full screen" : "Цео екран",
    "Save failed. Click to retry." : "Грешка при чувању. Кликните да покушате поново.",
    "Set category" : "Одаберите категорију",
    "Category" : "Категорија",
    "Uncategorized" : "Некатегоризовано",
    "Click here to save manually" : "Кликните овде да сачувате ручно",
    "Saving failed!" : "Снимање није успело!",
    "Last modified: {date}" : "Последња измена: {date}",
    "Note has unsaved changes" : "Белешка има несачуваних измена",
    "Subcategory" : "Подкатегорија",
    "_%n word_::_%n words_" : ["%n реч","%n речи","%n речи"],
    "_%n character_::_%n characters_" : ["%n карактер","%n карактера","%n карактера"],
    "Write down your thoughts without any distractions." : "Запишите Ваше мисли без ометања.",
    "Use Markdown markups to style your text." : "Користите Markdown језик да стилизујете текст.",
    "Organize your notes in categories." : "Организујте белешке у категорије.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте апликацију за мобилни да приступите Вашим белешкама где год да се налазите.",
    "Android app" : "Андроид апликација",
    "iOS app" : "iOS апликација",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Крените да пишете белешке кликајући „{newnote}“ из навигације апликације.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да направите подкатегорије користећи „/“ као разграничавач између категорије родитеља и подкатегорије, нпр. „{parent}/{sub}“",
    "Note not found." : "Белешка није нађена.",
    "Note is locked." : "Белешка је закључана.",
    "Insufficient storage." : "Недовољно места.",
    "See JavaScript console and server log for details." : "Погледајте JavaScript конзолу и дневник са сервера за детаље.",
    "Updating settings has failed." : "Ажурирање подешавања није успело.",
    "Error from Nextcloud server: {msg}" : "Грешка са Некстклауд сервера: {msg}",
    "Fetching notes has failed." : "Дохватање белешки није успело.",
    "Fetching note {id} has failed." : "Дохватање белешке {id} није успело.",
    "Refreshing note {id} has failed." : "Освежавање белешке {id} није успело.",
    "Renaming note {id} has failed." : "Преименовање белешке {id} није успело.",
    "Creating new note has failed." : "Прављење нове белешке није успело.",
    "Saving note {id} has failed." : "Чување белешке {id} није успело.",
    "Updating title for note {id} has failed." : "Промена наслова белешке {id} није успела.",
    "Undo delete has failed for note {title}." : "Опозивање брисања није успело за белешку {title}.",
    "Deleting note {id} has failed." : "Брисање белешке {id} није успело.",
    "Toggling favorite for note {id} has failed." : "Стављање/уклањање омиљене белешке {id} није успело.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешно ажурирање категорије белешке. Да ли у одредишни директоријум може да се пише?",
    "Updating the category for note {id} has failed." : "Ажурирање категорије белешке {id} није успело.",
    "Development Mode" : "Развојни режим",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Изгледа да је апликација белешки инсталирана из развојног извора. Молимо да је инсталирате из званичне <a href=\"%1$s\">Некстклауд продавнице</a>. Ако желите само да искомпајлирате апликацију Белешки, пратите <a href=\"%2$s\">инструкције за програмере</a>."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
